<template>
  <div class="editor_box">
    <div :id="ids" ref="editor" class="editor-quill" :style="sty"></div>
    <v-u slots ids="editor-upload" class="u" @path="onPath"
      ><button :id="ids + '-btn'"></button
    ></v-u>
  </div>
</template>

<script>
/* eslint-disable */
import Quill from "quill";
import "quill/dist/quill.snow.css";
import vU from "../upload/upload1";
export default {
  props: {
    content: String,
    readonly: {
      type: Boolean,
      default: false
    },
    ids: { type: String, default: "editor-quill" },
    timeout: { type: Number, default: 500 },
    option: {
      type: Array,
      default: () => {
        return [];
      }
    },
    sty: {
      type: Object,
      default: () => {
        return {};
      }
    },
    image: { type: String, default: "" }
  },
  components: { vU },
  data() {
    return {
      editor: null,
      time: null
    };
  },
  watch: {
    content(n) {
      this.editor.clipboard.dangerouslyPasteHTML(0, n);
    },
    image(n) {
      this.getPic(n);
    }
  },
  methods: {
    onPath(v) {
      this.getPic(v);
    },
    timer(fn) {
      if (this.time !== null) {
        clearTimeout(this.time);
        this.time = null;
      }
      this.time = setTimeout(() => {
        fn();
      }, this.timeout);
    },
    getPic(p) {
      // 插入图片
      let length = this.editor.getSelection().index;
      // 插入图片  res.url为服务器返回的图片地址
      this.editor.insertEmbed(length, "image", p);
      // 调整光标到最后
      this.editor.setSelection(length + 1);
    },
    init() {
      let that = this;
      this.editor.on("text-change", (delta, oldDelta, source) => {
        let text = that.editor.getText();
        let html = that.$refs.editor.children[0].innerHTML;
        html = this.$xss_switch.process(html);
        that.timer(() => {
          that.$emit("input", { text, html });
        });
      });
      this.editor.on("selection-change", e => {
        if (!e) {
          // console.log("离开");
          that.$emit("blur");
        } else {
          // console.log("进入");
          that.$emit("focus");
        }
      });
      that.$emit("ready");
    }
  },
  mounted() {
    let that = this;
    this.config = [
      ["bold", "italic", "underline"], // 加粗 斜体 下划线 删除线
      // ["code-block"], // 引用  代码块
      // [{ header: 1 }, { header: 2 }], // 1、2 级标题
      [{ list: "ordered" }, { list: "bullet" }], // 有序、无序列表
      // [{ script: "sub" }, { script: "super" }], // 上标/下标
      [{ indent: "-1" }, { indent: "+1" }], // 缩进
      // [{'direction': 'rtl'}],                         // 文本方向
      [{ size: ["small", false, "large", "huge"] }], // 字体大小
      [{ header: [1, 2, 3, 4, 5, 6, false] }], // 标题
      [{ color: [] }, { background: [] }], // 字体颜色、字体背景颜色
      [{ font: [] }], // 字体种类
      [{ align: [] }], // 对齐方式
      // ["clean"], // 清除文本格式
      // "link",, "video"
      ["image", "upload"] // 链接、图片、视频
    ];

    if (this.option.length) {
      this.config = this.option;
    }
    let _t = this;
    this.editor = new Quill("#" + that.ids, {
      //  富文本编辑器配置
      modules: {
        toolbar: {
          container: this.config,
          handlers: {
            image: function(value) {
              if (value) {
                // _t.$emit("upload");
                demo.$.id(_t.ids + "-btn").click();
                // 触发input框选择图片文件
                // document.querySelector("#btn-upload").click();
              }
            },
            upload: function() {
              // 添加工具方法
              document.querySelector(".avatar-uploader input").click();
            }
          }
        }
      },
      theme: "snow", // 主题
      placeholder: "请输入正文",
      readOnly: that.readonly // 是否只读
    });
    if (this.content) {
      this.editor.clipboard.dangerouslyPasteHTML(this.content);
    }
    this.init();
  }
};
</script>
<style lang="less">
.editor {
  line-height: normal !important;
  height: 100%;
}
.ql-snow .ql-tooltip[data-mode="link"]::before {
  content: "请输入链接地址:" !important;
}
.ql-snow .ql-tooltip.ql-editing a.ql-action::after {
  border-right: 0px;
  content: "保存" !important;
  padding-right: 0px;
}

.ql-snow .ql-tooltip[data-mode="video"]::before {
  content: "请输入视频地址:" !important;
}

.ql-snow .ql-picker.ql-size .ql-picker-label::before,
.ql-snow .ql-picker.ql-size .ql-picker-item::before {
  content: "14px" !important;
}
.ql-snow .ql-picker.ql-size .ql-picker-label[data-value="small"]::before,
.ql-snow .ql-picker.ql-size .ql-picker-item[data-value="small"]::before {
  content: "10px" !important;
}
.ql-snow .ql-picker.ql-size .ql-picker-label[data-value="large"]::before,
.ql-snow .ql-picker.ql-size .ql-picker-item[data-value="large"]::before {
  content: "18px" !important;
}
.ql-snow .ql-picker.ql-size .ql-picker-label[data-value="huge"]::before,
.ql-snow .ql-picker.ql-size .ql-picker-item[data-value="huge"]::before {
  content: "32px" !important;
}

.ql-snow .ql-picker.ql-header .ql-picker-label::before,
.ql-snow .ql-picker.ql-header .ql-picker-item::before {
  content: "文本" !important;
}
.ql-snow .ql-picker.ql-header .ql-picker-label[data-value="1"]::before,
.ql-snow .ql-picker.ql-header .ql-picker-item[data-value="1"]::before {
  content: "标题1" !important;
}
.ql-snow .ql-picker.ql-header .ql-picker-label[data-value="2"]::before,
.ql-snow .ql-picker.ql-header .ql-picker-item[data-value="2"]::before {
  content: "标题2" !important;
}
.ql-snow .ql-picker.ql-header .ql-picker-label[data-value="3"]::before,
.ql-snow .ql-picker.ql-header .ql-picker-item[data-value="3"]::before {
  content: "标题3" !important;
}
.ql-snow .ql-picker.ql-header .ql-picker-label[data-value="4"]::before,
.ql-snow .ql-picker.ql-header .ql-picker-item[data-value="4"]::before {
  content: "标题4" !important;
}
.ql-snow .ql-picker.ql-header .ql-picker-label[data-value="5"]::before,
.ql-snow .ql-picker.ql-header .ql-picker-item[data-value="5"]::before {
  content: "标题5" !important;
}
.ql-snow .ql-picker.ql-header .ql-picker-label[data-value="6"]::before,
.ql-snow .ql-picker.ql-header .ql-picker-item[data-value="6"]::before {
  content: "标题6" !important;
}

.ql-snow .ql-picker.ql-font .ql-picker-label::before,
.ql-snow .ql-picker.ql-font .ql-picker-item::before {
  content: "标准字体" !important;
}
.ql-snow .ql-picker.ql-font .ql-picker-label[data-value="serif"]::before,
.ql-snow .ql-picker.ql-font .ql-picker-item[data-value="serif"]::before {
  content: "衬线字体" !important;
}
.ql-snow .ql-picker.ql-font .ql-picker-label[data-value="monospace"]::before,
.ql-snow .ql-picker.ql-font .ql-picker-item[data-value="monospace"]::before {
  content: "等宽字体" !important;
}
</style>
<style lang="less" scoped>
.editor_box {
  height: 100%;
  * {
    -webkit-user-select: text !important;
  }
  .u {
    width: 1px;
    height: 1px;
    transform: scale(0);
  }
}

.ql-editor {
  white-space: normal !important;
}

.ql-container {
  white-space: pre-wrap !important;
}
</style>
